@@ -2,8 +2,8 @@ package MouseX::Getopt::OptionTypeMap;
 BEGIN {
   $MouseX::Getopt::OptionTypeMap::AUTHORITY = 'cpan:STEVAN';
 }
-BEGIN {
-  $MouseX::Getopt::OptionTypeMap::VERSION = '0.33';
+{
+  $MouseX::Getopt::OptionTypeMap::VERSION = '0.34';
 }
 # ABSTRACT: Storage for the option to type mappings
 
@@ -114,10 +114,6 @@ FUJI Goro <gfuji@cpan.org>
 
 =item *
 
-Tokuhiro Matsuno <tokuhirom@cpan.org>
-
-=item *
-
 Stevan Little <stevan@iinteractive.com>
 
 =item *
@@ -156,11 +152,15 @@ Avar Arnfjord Bjarmason <avar@cpan.org>
 
 Chris Prather <perigrin@cpan.org>
 
+=item *
+
+Mark Gardner <mjgardner@cpan.org>
+
 =back
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2010 by Infinity Interactive, Inc.
+This software is copyright (c) 2012 by Infinity Interactive, Inc.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
